Changelog
=========

0.8 (2018-08-03)
----------------

- Fixed tests to run with `zc.buildout >=1.7`.

- Moved source code to https://bitbucket.org/icemac/icemac.callonchange.

- Dropped support for Python < 2.7.

- Changed license from ZPL to MIT.


0.7.0 (2011-01-18)
------------------

- Added new option to run the utility immediately after invoking
  callonchange. This option was also added to the default options when using
  the recipe.


0.6.1 (2010-12-11)
------------------

- Made tests more robust.

- Added more similar tools to the list.


0.6 (2010-07-28)
----------------

- Added compatibility with Python 2.4.

- Now officially supporting Python 2.6 and 2.7, too.


Older changes
-------------

- See `OLD_CHANGES.rst` inside the package.

